home | help
GMX-SASA(1)			     GROMACS			     GMX-SASA(1)

NAME
     gmx-sasa - Compute solvent accessible surface area

SYNOPSIS
	gmx sasa [-f [<.xtc/.trr/...>]] [-s [<.tpr/.gro/...>]] [-n [<.ndx>]]
		 [-o [<.xvg>]] [-odg [<.xvg>]] [-or [<.xvg>]] [-oa [<.xvg>]]
		 [-tv [<.xvg>]] [-q [<.pdb>]] [-b <time>] [-e <time>]
		 [-dt <time>] [-tu <enum>] [-fgroup <selection>]
		 [-xvg <enum>] [-[no]rmpbc] [-[no]pbc] [-sf <file>]
		 [-selrpos <enum>] [-probe <real>] [-ndots <int>] [-[no]prot]
		 [-dgs <real>] [-surface <selection>] [-output <selection>]

DESCRIPTION
     gmx  sasa computes solvent accessible surface areas.  See Eisenhaber F, Li-
     jnzaad P, Argos P, Sander C, & Scharf M (1995) J. Comput. Chem. 16, 273-284
     for the algorithm used.  With -q, the Connolly surface can be generated  as
     well  in a .pdb file where the nodes are represented as atoms and the edges
     connecting the nearest nodes as CONECT records.  -odg allows for estimation
     of solvation free energies from per-atom  solvation  energies  per  exposed
     surface area.

     The  program  requires a selection for the surface calculation to be speci-
     fied with -surface. This should always consist of all non-solvent atoms  in
     the  system. The area of this group is always calculated. Optionally, -out-
     put can specify additional selections, which should be subsets of the  cal-
     culation group.  The solvent-accessible areas for these groups are also ex-
     tracted from the full surface.

     The  average  and standard deviation of the area over the trajectory can be
     calculated per residue and atom (options -or and -oa).

     With the -tv option the total volume and density of  the  molecule  can  be
     computed.	With -pbc (the default), you must ensure that your molecule/sur-
     face group is not split across PBC.  Otherwise, you will  get  non-sensical
     results.  Please also consider whether the normal probe radius is appropri-
     ate  in  this  case or whether you would rather use, e.g., 0. It is good to
     keep in mind that the results for volume and density are very  approximate.
     For  example,  in	ice  Ih, one can easily fit water molecules in the pores
     which would yield a volume that is too low, and surface  area  and  density
     that are both too high.

OPTIONS
     Options to specify input files:

     -f [<.xtc/.trr/...>] (traj.xtc) (Optional)
	    Input  trajectory  or  single configuration: xtc trr cpt gro g96 pdb
	    tng h5md

     -s [<.tpr/.gro/...>] (topol.tpr) (Optional)
	    Input structure: tpr gro g96 pdb brk ent

     -n [<.ndx>] (index.ndx) (Optional)
	    Extra index groups

     Options to specify output files:

     -o [<.xvg>] (area.xvg)
	    Total area as a function of time

     -odg [<.xvg>] (dgsolv.xvg) (Optional)
	    Estimated solvation free energy as a function of time

     -or [<.xvg>] (resarea.xvg) (Optional)
	    Average area per residue

     -oa [<.xvg>] (atomarea.xvg) (Optional)
	    Average area per atom

     -tv [<.xvg>] (volume.xvg) (Optional)
	    Total volume and density as a function of time

     -q [<.pdb>] (connolly.pdb) (Optional)
	    PDB file for Connolly surface

     Other options:

     -b <time> (0)
	    First frame (ps) to read from trajectory

     -e <time> (0)
	    Last frame (ps) to read from trajectory

     -dt <time> (0)
	    Only use frame if t MOD dt == first time (ps)

     -tu <enum> (ps)
	    Unit for time values: fs, ps, ns, us, ms, s

     -fgroup <selection>
	    Atoms stored in the trajectory file (if  not  set,	assume	first  N
	    atoms)

     -xvg <enum> (xmgrace)
	    Plot formatting: xmgrace, xmgr, none

     -[no]rmpbc (yes)
	    Make molecules whole for each frame

     -[no]pbc (yes)
	    Use periodic boundary conditions for distance calculation

     -sf <file>
	    Provide selections from files

     -selrpos <enum> (atom)
	    Selection  reference  positions:  atom,  res_com,  res_cog, mol_com,
	    mol_cog, whole_res_com, whole_res_cog, whole_mol_com, whole_mol_cog,
	    part_res_com, part_res_cog, part_mol_com, part_mol_cog, dyn_res_com,
	    dyn_res_cog, dyn_mol_com, dyn_mol_cog

     -probe <real> (0.14)
	    Radius of the solvent probe (nm)

     -ndots <int> (24)
	    Number of dots per sphere, more dots means more accuracy

     -[no]prot (yes)
	    Output the protein to the Connolly .pdb file too

     -dgs <real> (0)
	    Default value for solvation free energy per area (kJ/mol/nm^2)

     -surface <selection>
	    Surface calculation selection

     -output <selection>
	    Output selection(s)

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026			     GMX-SASA(1)

home | help